summaryrefslogtreecommitdiff
path: root/src/ipa/raspberrypi/controller/rpi/alsc.hpp
diff options
context:
space:
mode:
authorNaushir Patuck <naush@raspberrypi.com>2022-07-27 09:55:17 +0100
committerLaurent Pinchart <laurent.pinchart@ideasonboard.com>2022-07-27 18:12:12 +0300
commit177df04d2b7f357ebe41f1a9809ab68b6f948082 (patch)
tree062bc7f480d96629461487c63b4762936a7dcb22 /src/ipa/raspberrypi/controller/rpi/alsc.hpp
parentb4a3eb6b98ce65a6c9323368fa0afcb887739628 (diff)
ipa: raspberrypi: Code refactoring to match style guidelines
Refactor all the source files in src/ipa/raspberrypi/ to match the recommended formatting guidelines for the libcamera project. The vast majority of changes in this commit comprise of switching from snake_case to CamelCase, and starting class member functions with a lower case character. Signed-off-by: Naushir Patuck <naush@raspberrypi.com> Reviewed-by: Laurent Pinchart <laurent.pinchart@ideasonboard.com> Signed-off-by: Laurent Pinchart <laurent.pinchart@ideasonboard.com>
Diffstat (limited to 'src/ipa/raspberrypi/controller/rpi/alsc.hpp')
-rw-r--r--src/ipa/raspberrypi/controller/rpi/alsc.hpp86
1 files changed, 43 insertions, 43 deletions
diff --git a/src/ipa/raspberrypi/controller/rpi/alsc.hpp b/src/ipa/raspberrypi/controller/rpi/alsc.hpp
index d1dbe0d1..7a0949d1 100644
--- a/src/ipa/raspberrypi/controller/rpi/alsc.hpp
+++ b/src/ipa/raspberrypi/controller/rpi/alsc.hpp
@@ -24,24 +24,24 @@ struct AlscCalibration {
struct AlscConfig {
// Only repeat the ALSC calculation every "this many" frames
- uint16_t frame_period;
+ uint16_t framePeriod;
// number of initial frames for which speed taken as 1.0 (maximum)
- uint16_t startup_frames;
+ uint16_t startupFrames;
// IIR filter speed applied to algorithm results
double speed;
- double sigma_Cr;
- double sigma_Cb;
- double min_count;
- uint16_t min_G;
+ double sigmaCr;
+ double sigmaCb;
+ double minCount;
+ uint16_t minG;
double omega;
- uint32_t n_iter;
- double luminance_lut[ALSC_CELLS_X * ALSC_CELLS_Y];
- double luminance_strength;
- std::vector<AlscCalibration> calibrations_Cr;
- std::vector<AlscCalibration> calibrations_Cb;
- double default_ct; // colour temperature if no metadata found
+ uint32_t nIter;
+ double luminanceLut[ALSC_CELLS_X * ALSC_CELLS_Y];
+ double luminanceStrength;
+ std::vector<AlscCalibration> calibrationsCr;
+ std::vector<AlscCalibration> calibrationsCb;
+ double defaultCt; // colour temperature if no metadata found
double threshold; // iteration termination threshold
- double lambda_bound; // upper/lower bound for lambda from a value of 1
+ double lambdaBound; // upper/lower bound for lambda from a value of 1
};
class Alsc : public Algorithm
@@ -49,58 +49,58 @@ class Alsc : public Algorithm
public:
Alsc(Controller *controller = NULL);
~Alsc();
- char const *Name() const override;
- void Initialise() override;
- void SwitchMode(CameraMode const &camera_mode, Metadata *metadata) override;
- void Read(boost::property_tree::ptree const &params) override;
- void Prepare(Metadata *image_metadata) override;
- void Process(StatisticsPtr &stats, Metadata *image_metadata) override;
+ char const *name() const override;
+ void initialise() override;
+ void switchMode(CameraMode const &cameraMode, Metadata *metadata) override;
+ void read(boost::property_tree::ptree const &params) override;
+ void prepare(Metadata *imageMetadata) override;
+ void process(StatisticsPtr &stats, Metadata *imageMetadata) override;
private:
// configuration is read-only, and available to both threads
AlscConfig config_;
- bool first_time_;
- CameraMode camera_mode_;
- double luminance_table_[ALSC_CELLS_X * ALSC_CELLS_Y];
- std::thread async_thread_;
+ bool firstTime_;
+ CameraMode cameraMode_;
+ double luminanceTable_[ALSC_CELLS_X * ALSC_CELLS_Y];
+ std::thread asyncThread_;
void asyncFunc(); // asynchronous thread function
std::mutex mutex_;
// condvar for async thread to wait on
- std::condition_variable async_signal_;
+ std::condition_variable asyncSignal_;
// condvar for synchronous thread to wait on
- std::condition_variable sync_signal_;
+ std::condition_variable syncSignal_;
// for sync thread to check if async thread finished (requires mutex)
- bool async_finished_;
+ bool asyncFinished_;
// for async thread to check if it's been told to run (requires mutex)
- bool async_start_;
+ bool asyncStart_;
// for async thread to check if it's been told to quit (requires mutex)
- bool async_abort_;
+ bool asyncAbort_;
// The following are only for the synchronous thread to use:
// for sync thread to note its has asked async thread to run
- bool async_started_;
- // counts up to frame_period before restarting the async thread
- int frame_phase_;
- // counts up to startup_frames
- int frame_count_;
- // counts up to startup_frames for Process function
- int frame_count2_;
- double sync_results_[3][ALSC_CELLS_Y][ALSC_CELLS_X];
- double prev_sync_results_[3][ALSC_CELLS_Y][ALSC_CELLS_X];
+ bool asyncStarted_;
+ // counts up to framePeriod before restarting the async thread
+ int framePhase_;
+ // counts up to startupFrames
+ int frameCount_;
+ // counts up to startupFrames for Process function
+ int frameCount2_;
+ double syncResults_[3][ALSC_CELLS_Y][ALSC_CELLS_X];
+ double prevSyncResults_[3][ALSC_CELLS_Y][ALSC_CELLS_X];
void waitForAysncThread();
// The following are for the asynchronous thread to use, though the main
// thread can set/reset them if the async thread is known to be idle:
- void restartAsync(StatisticsPtr &stats, Metadata *image_metadata);
+ void restartAsync(StatisticsPtr &stats, Metadata *imageMetadata);
// copy out the results from the async thread so that it can be restarted
void fetchAsyncResults();
double ct_;
bcm2835_isp_stats_region statistics_[ALSC_CELLS_Y * ALSC_CELLS_X];
- double async_results_[3][ALSC_CELLS_Y][ALSC_CELLS_X];
- double async_lambda_r_[ALSC_CELLS_X * ALSC_CELLS_Y];
- double async_lambda_b_[ALSC_CELLS_X * ALSC_CELLS_Y];
+ double asyncResults_[3][ALSC_CELLS_Y][ALSC_CELLS_X];
+ double asyncLambdaR_[ALSC_CELLS_X * ALSC_CELLS_Y];
+ double asyncLambdaB_[ALSC_CELLS_X * ALSC_CELLS_Y];
void doAlsc();
- double lambda_r_[ALSC_CELLS_X * ALSC_CELLS_Y];
- double lambda_b_[ALSC_CELLS_X * ALSC_CELLS_Y];
+ double lambdaR_[ALSC_CELLS_X * ALSC_CELLS_Y];
+ double lambdaB_[ALSC_CELLS_X * ALSC_CELLS_Y];
};
} // namespace RPiController